Skip to contents

Computes continuous steady-state molecular concentration fields from discrete mRNA transcript or protein detection coordinates using a physically motivated diffusion-clearance model. The screened Poisson PDE is solved numerically using one of three methods: finite-difference sparse linear system ("fd"), Green's function FFT convolution ("green"), or Gaussian kernel density ("kde").

Author

Maintainer: Raredon Laboratory raredon@yale.edu